@@ -3,6 +3,8 @@ use governor::NotUntil;
 use serde::Deserialize;
 use std::fmt;
 use Gender::*;
+use serde_json;
+use std::str::FromStr;
 
 #[derive(Clone, Copy, Deserialize, Debug)]
 pub enum Gender {
@@ -17,6 +19,14 @@ pub enum Gender {
     Any
 }
 
+impl FromStr for Gender {
+    type Err = serde_json::error::Error;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        serde_json::from_str::<Gender>(format!("\"{}\"", s).as_str())
+    }
+}
+
 impl fmt::Display for Gender {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
